%%%% Matlab code for Arellano and Bonhomme, "Quantile Selection Models"
%%%% This code computes the equilibrium in Section 4.3
%%%% The code makes use of rq.m
%%%% It also use the files data_GE_interact.out
%%%% The output is Matresults


clear all;
clc;

% values of rho

rho_m_s=-7.638;
rho_m_m=-1.482;

rho_f_s=-.482;
rho_f_m=-1.035;


nbvar=86;

% Load data
data = csv2mat_numeric('C:\Dfile\Dossiers\Textes\Quantiles\Codes\Quantiles_stata\data_GE_interact.out');
Vec=struct2cell(data);
Vec=cell2mat(Vec);
[Nvar a]=size(Vec);
N=Nvar/nbvar;
Mat=Vec(1:N);
for j=2:nbvar
    Mat=[Mat Vec((j-1)*N+1:j*N)];
end
clear Vec data 

    


% Keep only working individiduals
[N col]=size(Mat);
D=Mat(1:N,2);
Y=Mat(1:N,1);
pZ=Mat(1:N,3);
X=Mat(1:N,4:col-5);
Z=Mat(1:N,col-4:col-1);
Year=Mat(1:N,col);

Mat1=Mat(D==1,1:col);
[N1 col1]=size(Mat1);

Y1=Mat1(1:N1,1);
pZ1=Mat1(1:N1,3);
X1=Mat1(1:N1,4:col-5);
Z1=Mat1(1:N1,col-4:col-1);


% Rescale X (note: if rescale X's in order to avoid ill-conditioning, then some changes to the code are needed)
%X1=X1./(kron(ones(N1,1),mean(X1)));
%X1=(X1-ones(N1,1)*mean(X1))./(ones(N1,1)*std(X1));
%X=(X-ones(N,1)*mean(X))./(ones(N,1)*std(X));

Year1=Mat1(1:N1,col);
[Nx colx]=size(X1);

% Start loop on tau
vectau=(.01:.01:.99)';
[t n]=size(vectau);

matbeta=zeros(colx+1,t);

for j=1:t
    tau=vectau(j);
    G=(1-X1(:,1)).*(1-X1(:,2)).*copulacdf('Frank',[tau*ones(N1,1) pZ1],rho_m_s)./pZ1...
    +(X1(:,1)).*(1-X1(:,2)).*copulacdf('Frank',[tau*ones(N1,1) pZ1],rho_f_s)./pZ1...
    +(1-X1(:,1)).*(X1(:,2)).*copulacdf('Frank',[tau*ones(N1,1) pZ1],rho_m_m)./pZ1...
    +(X1(:,1)).*(X1(:,2)).*copulacdf('Frank',[tau*ones(N1,1) pZ1],rho_f_m)./pZ1;
    beta=rq([ones(N1,1) X1],Y1,G);
    matbeta(1:colx+1,j)=beta;
end

save('C:\Dfile\Dossiers\Textes\Quantiles\Codes\Quantiles_stata\Matbeta','matbeta','-ASCII');

% price of skill
Mat_skills=zeros(23,2);
% non educated
Mat_skills(:,1)=[0;matbeta(36:57,50)];
% educated
Mat_skills(:,2)=[0;matbeta(36:57,50)]+matbeta(4,50)*ones(23,1)+[0;matbeta(58:79,50)];

Var_skills=matbeta(4,50)*X(:,3)+X(:,35:56)*matbeta(36:57,50)+...
    X(:,57:78)*matbeta(58:79,50);

Var_skills1=matbeta(4,50)*X1(:,3)+X1(:,35:56)*matbeta(36:57,50)+...
    X1(:,57:78)*matbeta(58:79,50);

% re-estimation of participation
% probit of participation on a constant, skills, and controls and
% instruments
Xtilde=[X(:,1:2) X(:,4:34)];
coeff_partic=glmfit([Var_skills Z Xtilde],D,'binomial','link','probit');

% re-compute the propensity score
X1tilde=[X1(:,1:2) X1(:,4:34)];
pZ1_recomp=normcdf(coeff_partic(2)*Var_skills1+[ones(N1,1) Z1 X1tilde]*[coeff_partic(1);coeff_partic(3:39)]);

% quantile regression: second run (fixing log(r_t^S))
matbeta_recomp=zeros(27+1,t);

for j=1:t
    tau=vectau(j);
    G=(1-X1(:,1)).*(1-X1(:,2)).*copulacdf('Frank',[tau*ones(N1,1) pZ1_recomp],rho_m_s)./pZ1_recomp...
    +(X1(:,1)).*(1-X1(:,2)).*copulacdf('Frank',[tau*ones(N1,1) pZ1_recomp],rho_f_s)./pZ1_recomp...
    +(1-X1(:,1)).*(X1(:,2)).*copulacdf('Frank',[tau*ones(N1,1) pZ1_recomp],rho_m_m)./pZ1_recomp...
    +(X1(:,1)).*(X1(:,2)).*copulacdf('Frank',[tau*ones(N1,1) pZ1_recomp],rho_f_m)./pZ1_recomp;
    beta=rq([ones(N1,1) X1tilde],Y1-Var_skills1,G);
    matbeta_recomp(1:33+1,j)=beta;
end


% calibrated parameters:
% Labor share (Blundell and Bond 2000)
theta=.6;
% Elasticity of substitution (Card and Lemieux 2001)
rho_elas=.4;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Counterfactual: out-of-work income %%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% 1978 out-of-work income (mean of income by gender and marital status)
Ztilde=Z;
m00_78=(sum(Z(:,1).*(Year==78).*(X(:,1)==0).*(X(:,2)==0))/...
        sum((Year==78).*(X(:,1)==0).*(X(:,2)==0)));
m10_78=(sum(Z(:,2).*(Year==78).*(X(:,1)==1).*(X(:,2)==0))/...
        sum((Year==78).*(X(:,1)==1).*(X(:,2)==0)));
m01_78=(sum(Z(:,3).*(Year==78).*(X(:,1)==0).*(X(:,2)==1))/...
        sum((Year==78).*(X(:,1)==0).*(X(:,2)==1)));
m11_78=(sum(Z(:,4).*(Year==78).*(X(:,1)==1).*(X(:,2)==1))/...
        sum((Year==78).*(X(:,1)==1).*(X(:,2)==1)));
    
for j=78:100
    m00=(sum(Z(:,1).*(Year==j).*(X(:,1)==0).*(X(:,2)==0))/...
        sum((Year==j).*(X(:,1)==0).*(X(:,2)==0)));
    Ztilde(:,1)=Ztilde(:,1)+(m00_78-m00).*(Year==j).*(X(:,1)==0).*(X(:,2)==0);
    m10=(sum(Z(:,2).*(Year==j).*(X(:,1)==1).*(X(:,2)==0))/...
        sum((Year==j).*(X(:,1)==1).*(X(:,2)==0)));
    Ztilde(:,2)=Ztilde(:,2)+(m10_78-m10).*(Year==j).*(X(:,1)==1).*(X(:,2)==0);
    m01=(sum(Z(:,3).*(Year==j).*(X(:,1)==0).*(X(:,2)==1))/...
        sum((Year==j).*(X(:,1)==0).*(X(:,2)==1)));
    Ztilde(:,3)=Ztilde(:,3)+(m01_78-m01).*(Year==j).*(X(:,1)==0).*(X(:,2)==1);
    m11=(sum(Z(:,4).*(Year==j).*(X(:,1)==1).*(X(:,2)==1))/...
        sum((Year==j).*(X(:,1)==1).*(X(:,2)==1)));
    Ztilde(:,4)=Ztilde(:,4)+(m11_78-m11).*(Year==j).*(X(:,1)==1).*(X(:,2)==1);
end

% Supply of skills (Appendix H in the paper)
Mat_supply=zeros(23,2);
for j=1:23
    Mat_supply(j,1)=log(sum(exp(Y1).*(X1(:,3)==0).*(Year1==j+77)));
    Mat_supply(j,2)=log(sum(exp(Y1).*(X1(:,3)==1).*(Year1==j+77)));
end

Mat_supply=Mat_supply-Mat_skills;

% Technical progress (appendix H)
Mat_prog=zeros(23,1);
for j=1:23
    Mat_prog(j,1)=1/(1+exp(-(Mat_skills(j,2)-Mat_skills(j,1))+...
        (rho_elas-1)*(Mat_supply(j,2)-Mat_supply(j,1))));
end

% Total labor (note: a_t corresponds to educated here, 1-a_t to non-educated)
Mat_lab=zeros(23,1);
for j=1:23
    Mat_lab(j,1)=(Mat_prog(j,1)*(exp(Mat_supply(j,2)))^(rho_elas)+(1-Mat_prog(j,1))*(exp(Mat_supply(j,1)))^(rho_elas))^(1/rho_elas);
end

% supply of skills: check the formula 
Mat_supply_check=zeros(23,2);
for j=1:23
    
    pZ_t=normcdf(coeff_partic(2)*Mat_skills(j,1)+[ones(N,1) Z Xtilde]*[coeff_partic(1);coeff_partic(3:39)]);
    
    Mat_inter1_m_s=exp([ones(N,1) Xtilde]*matbeta_recomp).*exp(-rho_m_s*ones(N,1)*vectau(:)')...
        .*(1-exp(-rho_m_s*pZ_t*ones(1,99)))./...
        ((1-exp(-rho_m_s))-(1-exp(-rho_m_s*ones(N,1)*vectau(:)')).*(1-exp(-rho_m_s*pZ_t*ones(1,99))));
    Mat_inter1_f_s=exp([ones(N,1) Xtilde]*matbeta_recomp).*exp(-rho_f_s*ones(N,1)*vectau(:)')...
        .*(1-exp(-rho_f_s*pZ_t*ones(1,99)))./...
        ((1-exp(-rho_f_s))-(1-exp(-rho_f_s*ones(N,1)*vectau(:)')).*(1-exp(-rho_f_s*pZ_t*ones(1,99))));
    Mat_inter1_m_m=exp([ones(N,1) Xtilde]*matbeta_recomp).*exp(-rho_m_m*ones(N,1)*vectau(:)')...
        .*(1-exp(-rho_m_m*pZ_t*ones(1,99)))./...
        ((1-exp(-rho_m_m))-(1-exp(-rho_m_m*ones(N,1)*vectau(:)')).*(1-exp(-rho_m_m*pZ_t*ones(1,99))));
    Mat_inter1_f_m=exp([ones(N,1) Xtilde]*matbeta_recomp).*exp(-rho_f_m*ones(N,1)*vectau(:)')...
        .*(1-exp(-rho_f_m*pZ_t*ones(1,99)))./...
        ((1-exp(-rho_f_m))-(1-exp(-rho_f_m*ones(N,1)*vectau(:)')).*(1-exp(-rho_f_m*pZ_t*ones(1,99))));
    
    meanMat_inter1=(1-X(:,1)).*(1-X(:,2)).*mean(Mat_inter1_m_s')'...
    +(X(:,1)).*(1-X(:,2)).*mean(Mat_inter1_f_s')'...
    +(1-X(:,1)).*(X(:,2)).*mean(Mat_inter1_m_m')'...
    +(X(:,1)).*(X(:,2)).*mean(Mat_inter1_f_m')';
    
    clear Mat_inter1_m_s Mat_inter1_f_s Mat_inter1_m_m Mat_inter1_f_m
    clear Mat_inter2_m_s Mat_inter2_f_s Mat_inter2_m_m Mat_inter2_f_m

    Mat_supply_check(j,1)=log(sum((X(:,3)==0).*(Year==77+j).*meanMat_inter1));
    
    pZ_t=normcdf(coeff_partic(2)*Mat_skills(j,2)+[ones(N,1) Z Xtilde]*[coeff_partic(1);coeff_partic(3:39)]);
    
    Mat_inter2_m_s=exp([ones(N,1) Xtilde]*matbeta_recomp).*exp(-rho_m_s*ones(N,1)*vectau(:)')...
        .*(1-exp(-rho_m_s*pZ_t*ones(1,99)))./...
        ((1-exp(-rho_m_s))-(1-exp(-rho_m_s*ones(N,1)*vectau(:)')).*(1-exp(-rho_m_s*pZ_t*ones(1,99))));
    Mat_inter2_f_s=exp([ones(N,1) Xtilde]*matbeta_recomp).*exp(-rho_f_s*ones(N,1)*vectau(:)')...
        .*(1-exp(-rho_f_s*pZ_t*ones(1,99)))./...
        ((1-exp(-rho_f_s))-(1-exp(-rho_f_s*ones(N,1)*vectau(:)')).*(1-exp(-rho_f_s*pZ_t*ones(1,99))));
    Mat_inter2_m_m=exp([ones(N,1) Xtilde]*matbeta_recomp).*exp(-rho_m_m*ones(N,1)*vectau(:)')...
        .*(1-exp(-rho_m_m*pZ_t*ones(1,99)))./...
        ((1-exp(-rho_m_m))-(1-exp(-rho_m_m*ones(N,1)*vectau(:)')).*(1-exp(-rho_m_m*pZ_t*ones(1,99))));
    Mat_inter2_f_m=exp([ones(N,1) Xtilde]*matbeta_recomp).*exp(-rho_f_m*ones(N,1)*vectau(:)')...
        .*(1-exp(-rho_f_m*pZ_t*ones(1,99)))./...
        ((1-exp(-rho_f_m))-(1-exp(-rho_f_m*ones(N,1)*vectau(:)')).*(1-exp(-rho_f_m*pZ_t*ones(1,99))));
    
    meanMat_inter2=(1-X(:,1)).*(1-X(:,2)).*mean(Mat_inter2_m_s')'...
    +(X(:,1)).*(1-X(:,2)).*mean(Mat_inter2_f_s')'...
    +(1-X(:,1)).*(X(:,2)).*mean(Mat_inter2_m_m')'...
    +(X(:,1)).*(X(:,2)).*mean(Mat_inter2_f_m')';
    
    clear Mat_inter1_m_s Mat_inter1_f_s Mat_inter1_m_m Mat_inter1_f_m
    clear Mat_inter2_m_s Mat_inter2_f_s Mat_inter2_m_m Mat_inter2_f_m

    Mat_supply_check(j,2)=log(sum((X(:,3)==1).*(Year==77+j).*meanMat_inter2));

end

% check propensity score
MatpZ=zeros(23,2);
for j=1:23
    pZ_t=normcdf(coeff_partic(2)*Mat_skills(j,1)+[ones(N,1) Z Xtilde]*[coeff_partic(1);coeff_partic(3:39)]);
    MatpZ(j,1)=sum(pZ_t.*(Year==77+j).*(X(:,3)==0))/sum((Year==77+j).*(X(:,3)==0));
    pZ_t=normcdf(coeff_partic(2)*Mat_skills(j,2)+[ones(N,1) Z Xtilde]*[coeff_partic(1);coeff_partic(3:39)]);
    MatpZ(j,2)=sum(pZ_t.*(Year==77+j).*(X(:,3)==1))/sum((Year==77+j).*(X(:,3)==1));
end

TrueMatpZ=zeros(23,2);
for j=1:23
    TrueMatpZ(j,1)=sum(D.*(Year==77+j).*(X(:,3)==0))/sum((Year==77+j).*(X(:,3)==0));
    TrueMatpZ(j,2)=sum(D.*(Year==77+j).*(X(:,3)==1))/sum((Year==77+j).*(X(:,3)==1));
end

MatpZtilde=zeros(23,2);
for j=1:23
    pZ_t=normcdf(coeff_partic(2)*Mat_skills(j,1)+[ones(N,1) Ztilde Xtilde]*[coeff_partic(1);coeff_partic(3:39)]);
    MatpZtilde(j,1)=sum(pZ_t.*(Year==77+j).*(X(:,3)==0))/sum((Year==77+j).*(X(:,3)==0));
    pZ_t=normcdf(coeff_partic(2)*Mat_skills(j,2)+[ones(N,1) Ztilde Xtilde]*[coeff_partic(1);coeff_partic(3:39)]);
    MatpZtilde(j,2)=sum(pZ_t.*(Year==77+j).*(X(:,3)==1))/sum((Year==77+j).*(X(:,3)==1));
end


% recompute the price of skills
NewMat_skills=Mat_skills;
NewMat_supply=zeros(23,2);
NewMat_lab=zeros(23,1);
    
% Lopp by year
for j=1:23
    
    j
    
    % Fixed-point algorithm
    deltapar=1;
    while deltapar>.00001
        
        % new supply of skills
        
        pZ_t=normcdf(coeff_partic(2)*NewMat_skills(j,1)+[ones(N,1) Ztilde Xtilde]*[coeff_partic(1);coeff_partic(3:39)]);
        
        Mat_inter1_m_s=exp([ones(N,1) Xtilde]*matbeta_recomp).*exp(-rho_m_s*ones(N,1)*vectau(:)')...
            .*(1-exp(-rho_m_s*pZ_t*ones(1,99)))./...
            ((1-exp(-rho_m_s))-(1-exp(-rho_m_s*ones(N,1)*vectau(:)')).*(1-exp(-rho_m_s*pZ_t*ones(1,99))));
        Mat_inter1_f_s=exp([ones(N,1) Xtilde]*matbeta_recomp).*exp(-rho_f_s*ones(N,1)*vectau(:)')...
            .*(1-exp(-rho_f_s*pZ_t*ones(1,99)))./...
            ((1-exp(-rho_f_s))-(1-exp(-rho_f_s*ones(N,1)*vectau(:)')).*(1-exp(-rho_f_s*pZ_t*ones(1,99))));
        Mat_inter1_m_m=exp([ones(N,1) Xtilde]*matbeta_recomp).*exp(-rho_m_m*ones(N,1)*vectau(:)')...
            .*(1-exp(-rho_m_m*pZ_t*ones(1,99)))./...
            ((1-exp(-rho_m_m))-(1-exp(-rho_m_m*ones(N,1)*vectau(:)')).*(1-exp(-rho_m_m*pZ_t*ones(1,99))));
        Mat_inter1_f_m=exp([ones(N,1) Xtilde]*matbeta_recomp).*exp(-rho_f_m*ones(N,1)*vectau(:)')...
            .*(1-exp(-rho_f_m*pZ_t*ones(1,99)))./...
            ((1-exp(-rho_f_m))-(1-exp(-rho_f_m*ones(N,1)*vectau(:)')).*(1-exp(-rho_f_m*pZ_t*ones(1,99))));

        meanMat_inter1=(1-X(:,1)).*(1-X(:,2)).*mean(Mat_inter1_m_s')'...
        +(X(:,1)).*(1-X(:,2)).*mean(Mat_inter1_f_s')'...
        +(1-X(:,1)).*(X(:,2)).*mean(Mat_inter1_m_m')'...
        +(X(:,1)).*(X(:,2)).*mean(Mat_inter1_f_m')';

        clear Mat_inter1_m_s Mat_inter1_f_s Mat_inter1_m_m Mat_inter1_f_m
        clear Mat_inter2_m_s Mat_inter2_f_s Mat_inter2_m_m Mat_inter2_f_m

        NewMat_supply(j,1)=log(sum((X(:,3)==0).*(Year==77+j).*meanMat_inter1));

        pZ_t=normcdf(coeff_partic(2)*NewMat_skills(j,2)+[ones(N,1) Ztilde Xtilde]*[coeff_partic(1);coeff_partic(3:39)]);

        Mat_inter2_m_s=exp([ones(N,1) Xtilde]*matbeta_recomp).*exp(-rho_m_s*ones(N,1)*vectau(:)')...
            .*(1-exp(-rho_m_s*pZ_t*ones(1,99)))./...
            ((1-exp(-rho_m_s))-(1-exp(-rho_m_s*ones(N,1)*vectau(:)')).*(1-exp(-rho_m_s*pZ_t*ones(1,99))));
        Mat_inter2_f_s=exp([ones(N,1) Xtilde]*matbeta_recomp).*exp(-rho_f_s*ones(N,1)*vectau(:)')...
            .*(1-exp(-rho_f_s*pZ_t*ones(1,99)))./...
            ((1-exp(-rho_f_s))-(1-exp(-rho_f_s*ones(N,1)*vectau(:)')).*(1-exp(-rho_f_s*pZ_t*ones(1,99))));
        Mat_inter2_m_m=exp([ones(N,1) Xtilde]*matbeta_recomp).*exp(-rho_m_m*ones(N,1)*vectau(:)')...
            .*(1-exp(-rho_m_m*pZ_t*ones(1,99)))./...
            ((1-exp(-rho_m_m))-(1-exp(-rho_m_m*ones(N,1)*vectau(:)')).*(1-exp(-rho_m_m*pZ_t*ones(1,99))));
        Mat_inter2_f_m=exp([ones(N,1) Xtilde]*matbeta_recomp).*exp(-rho_f_m*ones(N,1)*vectau(:)')...
            .*(1-exp(-rho_f_m*pZ_t*ones(1,99)))./...
            ((1-exp(-rho_f_m))-(1-exp(-rho_f_m*ones(N,1)*vectau(:)')).*(1-exp(-rho_f_m*pZ_t*ones(1,99))));

        meanMat_inter2=(1-X(:,1)).*(1-X(:,2)).*mean(Mat_inter2_m_s')'...
        +(X(:,1)).*(1-X(:,2)).*mean(Mat_inter2_f_s')'...
        +(1-X(:,1)).*(X(:,2)).*mean(Mat_inter2_m_m')'...
        +(X(:,1)).*(X(:,2)).*mean(Mat_inter2_f_m')';

        clear Mat_inter1_m_s Mat_inter1_f_s Mat_inter1_m_m Mat_inter1_f_m
        clear Mat_inter2_m_s Mat_inter2_f_s Mat_inter2_m_m Mat_inter2_f_m


        NewMat_supply(j,2)=log(sum((X(:,3)==1).*(Year==77+j).*meanMat_inter2));
        
        % new total labor
        NewMat_lab(j,1)=(Mat_prog(j,1)*(exp(NewMat_supply(j,2)))^(rho_elas)+(1-Mat_prog(j,1))*(exp(NewMat_supply(j,1)))^(rho_elas))^(1/rho_elas);
        
        % new price
        Inter1=Mat_skills(j,1)+(1-theta)*log(Mat_lab(j,1)/NewMat_lab(j,1))+...
            (rho_elas-1)*(NewMat_supply(j,1)-log(NewMat_lab(j,1))-Mat_supply(j,1)+log(Mat_lab(j,1)));
        Inter2=Mat_skills(j,2)+(1-theta)*log(Mat_lab(j,1)/NewMat_lab(j,1))+...
            (rho_elas-1)*(NewMat_supply(j,2)-log(NewMat_lab(j,1))-Mat_supply(j,2)+log(Mat_lab(j,1)));
        
        % update
        deltapar=abs(Inter1-NewMat_skills(j,1))+abs(Inter2-NewMat_skills(j,2));
        NewMat_skills(j,1)=Inter1;
        NewMat_skills(j,2)=Inter2;
        
        NewMat_skills(j,1)
        NewMat_skills(j,2)
        deltapar
               
    end
end



% check propensity score


NewMatpZtilde=zeros(23,2);
for j=1:23
    pZ_t=normcdf(coeff_partic(2)*NewMat_skills(j,1)+[ones(N,1) Ztilde Xtilde]*[coeff_partic(1);coeff_partic(3:39)]);
    NewMatpZtilde(j,1)=sum(pZ_t.*(Year==77+j).*(X(:,3)==0))/sum((Year==77+j).*(X(:,3)==0));
    pZ_t=normcdf(coeff_partic(2)*NewMat_skills(j,2)+[ones(N,1) Ztilde Xtilde]*[coeff_partic(1);coeff_partic(3:39)]);
    NewMatpZtilde(j,2)=sum(pZ_t.*(Year==77+j).*(X(:,3)==1))/sum((Year==77+j).*(X(:,3)==1));
end

% Simulation of wages
% Expand sample 
M=20;
Ytot=kron([Y1;-1000*ones(N-N1,1)],ones(M,1));
N=N*M;
X=kron(X,ones(M,1));
Z=kron(Z,ones(M,1));
D=kron(D,ones(M,1));
Xtilde=kron(Xtilde,ones(M,1));
Ztilde=kron(Ztilde,ones(M,1));
Year=kron(Year,ones(M,1));

% individual ranks

Unif0=unifrnd(0,1,N,1);
Unif=floor(99*Unif0+1);
Vnif_m_s=-1/rho_m_s*log(ones(N,1)-(1-exp(-rho_m_s))*(((ones(N,1)./unifrnd(0,1,N,1))-ones(N,1)).*exp(-rho_m_s*Unif0)+ones(N,1)).^(-1));
Vnif_f_s=-1/rho_f_s*log(ones(N,1)-(1-exp(-rho_f_s))*(((ones(N,1)./unifrnd(0,1,N,1))-ones(N,1)).*exp(-rho_f_s*Unif0)+ones(N,1)).^(-1));
Vnif_m_m=-1/rho_m_m*log(ones(N,1)-(1-exp(-rho_m_m))*(((ones(N,1)./unifrnd(0,1,N,1))-ones(N,1)).*exp(-rho_m_m*Unif0)+ones(N,1)).^(-1));
Vnif_f_m=-1/rho_f_m*log(ones(N,1)-(1-exp(-rho_f_m))*(((ones(N,1)./unifrnd(0,1,N,1))-ones(N,1)).*exp(-rho_f_m*Unif0)+ones(N,1)).^(-1));

Vnif=(1-X(:,1)).*(1-X(:,2)).*Vnif_m_s...
    +(X(:,1)).*(1-X(:,2)).*Vnif_f_s...
    +(1-X(:,1)).*(X(:,2)).*Vnif_m_m...
    +(X(:,1)).*(X(:,2)).*Vnif_f_m;

% Wages (partial equilibrium)

Ystar_PE=zeros(N,1);
for j=1:N
   Ystar_PE(j)=[1 Xtilde(j,:)]*matbeta_recomp(:,Unif(j))+Mat_skills(Year(j)-77,X(j,3)+1);
end

% Wages (general equilibrium)
Ystar_GE=zeros(N,1);
for j=1:N
   Ystar_GE(j)=[1 Xtilde(j,:)]*matbeta_recomp(:,Unif(j))+NewMat_skills(Year(j)-77,X(j,3)+1);
end

% propensity score (original)
pZ_orig=zeros(N,1);
for j=1:N
    pZ_orig(j)=normcdf(coeff_partic(2)*Mat_skills(Year(j)-77,X(j,3)+1)+[1 Z(j,:) Xtilde(j,:)]*[coeff_partic(1);coeff_partic(3:39)]);
end

% propensity score (at counterfactual Z, partial equilibrium)
pZ_PE=zeros(N,1);
for j=1:N
    pZ_PE(j)=normcdf(coeff_partic(2)*Mat_skills(Year(j)-77,X(j,3)+1)+[1 Ztilde(j,:) Xtilde(j,:)]*[coeff_partic(1);coeff_partic(3:39)]);
end

% propensity score (at counterfactual Z, general equilibrium)
pZ_GE=zeros(N,1);
for j=1:N
    pZ_GE(j)=normcdf(coeff_partic(2)*NewMat_skills(Year(j)-77,X(j,3)+1)+[1 Ztilde(j,:) Xtilde(j,:)]*[coeff_partic(1);coeff_partic(3:39)]);
end

% Participation 
D_orig=(Vnif<=pZ_orig);
D_PE=(Vnif<=pZ_PE);
D_GE=(Vnif<=pZ_GE);

% graph potential wages
Mat_logwage=[Year Ystar_PE Ystar_GE];
Mat_logwage=sortrows(Mat_logwage);
Year_s=Mat_logwage(:,1);
Ystar_PE_s=Mat_logwage(:,2);
Ystar_GE_s=Mat_logwage(:,3);


Mat_quant_PE=zeros(23,3);
Mat_quant_GE=zeros(23,3);
beg_y=1;
for j=1:23
   count_y=sum(Year_s==j+77);
   Y_inter=Ystar_PE_s(beg_y:beg_y+count_y-1);
   Mat_quant_PE(j,:)=quantile(Y_inter,[.1;.5;.9]);
   Y_inter=Ystar_GE_s(beg_y:beg_y+count_y-1);
   Mat_quant_GE(j,:)=quantile(Y_inter,[.1;.5;.9]);
   beg_y=beg_y+count_y;
end

hold off
plot((1:1:23),Mat_quant_PE,'b');
hold on
plot((1:1:23),Mat_quant_GE,'r');
hold off

Matresults=[Year X(:,1) X(:,3) D Ytot D_orig D_PE D_GE Ystar_PE Ystar_GE];

save('C:\Dfile\Dossiers\Textes\Quantiles\Codes\Quantiles_stata\Matresults.txt','Matresults','-ASCII');



