%%%% Matlab code for Arellano and Bonhomme, "Quantile Selection Models"
%%%% This code estimates the quantiles of latent outcomes for the generalized Frank.
%%%% Figure 4 in the paper.

%%%% The code uses rq.m, data1.out and data2.out


clear all;
clc;

% values of copula parameters

% males, singles
reversed_m_s=1;
theta_m_s=15;
delta_m_s=.45;

% males, married
reversed_m_m=0;
theta_m_m=27;
delta_m_m=.05;


% females, singles
reversed_f_s=1;
theta_f_s=13;
delta_f_s=.05;

% females, married
reversed_f_m=0;
theta_f_m=3;
delta_f_m=.15;




nbvar=32;

% Load data
data = csv2mat_numeric('C:\Dfile\Dossiers\Textes\Quantiles\Codes\Quantiles_stata\data_1.out');
Vec_m=struct2cell(data);
Vec_m=cell2mat(Vec_m);
[Nvar a]=size(Vec_m);
N=Nvar/nbvar;
Mat_m=Vec_m(1:N);
for j=2:nbvar
    Mat_m=[Mat_m Vec_m((j-1)*N+1:j*N)];
end

data = csv2mat_numeric('C:\Dfile\Dossiers\Textes\Quantiles\Codes\Quantiles_stata\data_2.out');
Vec_f=struct2cell(data);
Vec_f=cell2mat(Vec_f);
[Nvar a]=size(Vec_f);
N=Nvar/nbvar;
Mat_f=Vec_f(1:N);
for j=2:nbvar
    Mat_f=[Mat_f Vec_f((j-1)*N+1:j*N)];
end

clear Vec_m Vec_f data 


% Gender 
sex=0;    
    

% Loop on marital status
for ma=0:1

if sex==0    
    Mat=Mat_m;
   
elseif sex==1
    Mat=Mat_f;
   
end
    
% copula parameters
if sex==0 && ma==0    
     theta=theta_m_s;
     delta=delta_m_s;
     reversed=reversed_m_s;
elseif sex==0 && ma==1    
     theta=theta_m_m;
     delta=delta_m_m;
     reversed=reversed_m_m;
elseif sex==1 && ma==0    
     theta=theta_f_s;
     delta=delta_f_s;
     reversed=reversed_f_s;
elseif sex==1 && ma==1    
     theta=theta_f_m;
     delta=delta_f_m;
     reversed=reversed_f_m;
end
    
% Keep single/married    
[Ntot coltot]=size(Mat);
Mat=Mat((Mat(:,1)==ma),2:coltot);


    
% Keep only working individiduals
[N col]=size(Mat);
D=Mat(1:N,2);
Mat1=Mat(D==1,1:col);

[N1 col1]=size(Mat1);

Y1=Mat1(1:N1,1);
pZ1=Mat1(1:N1,3);
X1=Mat1(1:N1,5:col-1);

% Rescale X
X1=(X1-ones(N1,1)*mean(X1))./(ones(N1,1)*std(X1));
Year1=Mat1(1:N1,col);
[Nx colx]=size(X1);

% Start loop on tau
vectau=(.01:.01:.99)';
[t n]=size(vectau);

matbeta=zeros(colx+1,t);

gamma=1-(1-delta).^(theta);
C=1/gamma;

for j=1:t
    tau=vectau(j);
    if reversed==0
        u1=1-(1-delta*tau).^(theta);
        v1=1-(1-delta*(1-pZ1)).^(theta);
        G=(tau-1/delta*(1-(1-C*u1.*v1).^(1/theta)))./pZ1;
    elseif reversed==1
        u1=1-(1-delta*(1-tau)).^(theta);
        v1=1-(1-delta*pZ1).^(theta);
        G=(pZ1-1/delta*(1-(1-C*u1.*v1).^(1/theta)))./pZ1;
    end
    beta=rq([ones(N1,1) X1],Y1,G);
    matbeta(1:colx+1,j)=beta;
end


% Simulation of wages

clear Mat1 X1 Y1 pZ1 N1 


% Expand sample 
M=20;
Mat=kron(ones(M,1),Mat);



[N col]=size(Mat);

X=Mat(1:N,5:col-1);
% Rescale X
X=(X-ones(N,1)*mean(X))./(ones(N,1)*std(X));

[Nx colx]=size(X);
pZ=Mat(1:N,3);
Year=Mat(1:N,col);

% Wages
Unif0=unifrnd(0,1,N,1);
Unif=floor(99*Unif0+1);

Ystar=zeros(N,1);
for j=1:N
   Ystar(j)=matbeta(1,Unif(j))+X(j,1:colx)*matbeta(2:colx+1,Unif(j));    
end



if sex==0 && ma==0
    Ystar_m_s=Ystar;
    Matres_m_s=[Ystar_m_s Year Mat(1:N,5:6)];
    
elseif sex==0 && ma==1
    Ystar_m_m=Ystar;
    Matres_m_m=[Ystar_m_m Year Mat(1:N,5:6)];
    
elseif sex==1 && ma==0
    Ystar_f_s=Ystar;
    Matres_f_s=[Ystar_f_s Year Mat(1:N,5:6)];
    
elseif sex==1 && ma==1
    Ystar_f_m=Ystar;
    Matres_f_m=[Ystar_f_m Year Mat(1:N,5:6)];
    
end

end

if sex==0
    Matres_m=[Matres_m_s' Matres_m_m']';
elseif sex==1
    Matres_f=[Matres_f_s' Matres_f_m']';
end

if sex==0
save ('C:\Dfile\Dossiers\Textes\Quantiles\Codes\Quantiles_stata\Matbb8_m.txt','Matres_m','-ASCII');
elseif sex==1
save ('C:\Dfile\Dossiers\Textes\Quantiles\Codes\Quantiles_stata\Matbb8_f.txt','Matres_f','-ASCII');
end
