%%%% Matlab code for Arellano and Bonhomme, "Quantile Selection Models"
%%%% This code estimates the bounds which are reported in Figure 5 in the
%%%% paper
%%%% It takes as inputs data_1.out and data2_out
%%%% These two files are constructed in Sample_construction.do
%%%% Note: there are two specifications: either trimmed, or untrimmed (see Sample_construction.do)
%%%% The code produces Matbounds_m and Matbounds_f

%%%% The code uses rq.m

clear all;
clc;



% values of rho
rho_m_s=-7.638;
rho_m_m=-1.482;


rho_f_s=-.482;
rho_f_m=-1.035;


nbvar=32;

% Load data
data = csv2mat_numeric('C:\Dfile\Dossiers\Textes\Quantiles\Codes\Quantiles_stata\data_1.out');
Vec_m=struct2cell(data);
Vec_m=cell2mat(Vec_m);
[Nvar a]=size(Vec_m);
N=Nvar/nbvar;
Mat_m=Vec_m(1:N);
for j=2:nbvar
    Mat_m=[Mat_m Vec_m((j-1)*N+1:j*N)];
end

data = csv2mat_numeric('C:\Dfile\Dossiers\Textes\Quantiles\Codes\Quantiles_stata\data_2.out');
Vec_f=struct2cell(data);
Vec_f=cell2mat(Vec_f);
[Nvar a]=size(Vec_f);
N=Nvar/nbvar;
Mat_f=Vec_f(1:N);
for j=2:nbvar
    Mat_f=[Mat_f Vec_f((j-1)*N+1:j*N)];
end

clear Vec_m Vec_f data 

sex=1;    
    



% Loop on marital status
for ma=0:1

if sex==0    
    Mat=Mat_m;
   
elseif sex==1
    Mat=Mat_f;
   
end
   

 
% copula parameters
if sex==0 && ma==0    
     rho=rho_m_s;
elseif sex==0 && ma==1    
     rho=rho_m_m;
elseif sex==1 && ma==0    
     rho=rho_f_s;
elseif sex==1 && ma==1    
     rho=rho_f_m;
end
    
% Keep single/married    
[Ntot coltot]=size(Mat);
Mat=Mat((Mat(:,1)==ma),2:coltot);


    
[N col]=size(Mat);
D=Mat(1:N,2);
suppZ=Mat(1:N,4);
X=Mat(1:N,5:col-1);
pZ=Mat(1:N,3);
Year=Mat(1:N,col);

% Keep only working individiduals
Mat1=Mat(D==1,1:col);

[N1 col1]=size(Mat1);

Y1=Mat1(1:N1,1);
pZ1=Mat1(1:N1,3);
suppZ1=Mat1(1:N1,4);
X1=Mat1(1:N1,5:col-1);

% Rescale X
X=(X-ones(N,1)*mean(X))./(ones(N,1)*std(X));
X1=(X1-ones(N1,1)*mean(X1))./(ones(N1,1)*std(X1));
Year1=Mat1(1:N1,col);
[Nx colx]=size(X1);

% Start loop on tau
vectau=(.01:.01:.99)';
[t n]=size(vectau);

% Large grid of tau's, to compute beta_G^(-1)
VectauL=(.01:.01:.99)';
[NtauL b]=size(VectauL);

matbeta=zeros(colx+1,t);

for j=1:t
    tau=vectau(j);
    G=copulacdf('Frank',[tau*ones(N1,1) pZ1],rho)./pZ1;
    beta=rq([ones(N1,1) X1],Y1,G);
    matbeta(1:colx+1,j)=beta;
end

clear Mat1 X1 Y1 pZ1 N1 

% Upper bound
matbeta_up=zeros(N,colx+1,t);
for j=1:t
    
            tau=min([vectau(j)./suppZ ones(N,1)]')';
            
            Gm=-1/rho*log(1-(1-exp(-rho))*(1-exp(-rho*tau.*suppZ))./(1-exp(-rho.*suppZ)));
            
                    [A ind]=min((ones(NtauL,1)*Gm'-VectauL*ones(1,N)).^2);
                    matbeta_up(1:N,1:colx+1,j)=matbeta(1:colx+1,ind)';
                    
end

% Lower bound
matbeta_low=zeros(N,colx+1,t);
for j=1:t
    
          tau=max([(vectau(j)+suppZ-1)./suppZ zeros(N,1)]')';
            
          Gm=-1/rho*log(1-(1-exp(-rho))*(1-exp(-rho*tau.*suppZ))./(1-exp(-rho.*suppZ)));
              
                    [A ind]=min((ones(NtauL,1)*Gm'-VectauL*ones(1,N)).^2);
                    matbeta_low(1:N,1:colx+1,j)=matbeta(1:colx+1,ind)';
end



% Simulation
% Expand sample 
M=20;
N=M*N;
X=kron(X,ones(M,1));
suppZ=kron(suppZ,ones(M,1));
pZ=kron(pZ,ones(M,1));
Mat=kron(Mat,ones(M,1));
Year=kron(Year,ones(M,1));



% Wages
Unif0=unifrnd(0,1,N,1);
Unif=floor(99*Unif0+1);

% Upper bound
Ystar_up=zeros(N,1);
for j=1:N
    jj=floor((j-1)/M)+1;
    Ystar_up(j)=matbeta_up(jj,1,Unif(j))+X(j,1:colx)*matbeta_up(jj,2:colx+1,Unif(j))';
end

clear matbeta_up



% Lower bound
Ystar_low=zeros(N,1);
for j=1:N
    jj=floor((j-1)/M)+1;
    Ystar_low(j)=matbeta_low(jj,1,Unif(j))+X(j,1:colx)*matbeta_low(jj,2:colx+1,Unif(j))';
end

clear matbeta_low


% Participation
Vnif=-1/rho*log(ones(N,1)-(1-exp(-rho))*(((ones(N,1)./unifrnd(0,1,N,1))-ones(N,1)).*exp(-rho*Unif0)+ones(N,1)).^(-1));

Dpred=(Vnif<=pZ);

if sex==0 && ma==0
    Matres_m_s=[Ystar_low Ystar_up Year Mat(1:N,5:6) Dpred];
    
elseif sex==0 && ma==1
    Matres_m_m=[Ystar_low Ystar_up Year Mat(1:N,5:6) Dpred];
    
elseif sex==1 && ma==0
     Matres_f_s=[Ystar_low Ystar_up Year Mat(1:N,5:6) Dpred];
    
elseif sex==1 && ma==1
    Matres_f_m=[Ystar_low Ystar_up Year Mat(1:N,5:6) Dpred];
    
end

end

if sex==0
    Matres_m=[Matres_m_s' Matres_m_m']';
elseif sex==1
    Matres_f=[Matres_f_s' Matres_f_m']';
end

if sex==0
save ('C:\Dfile\Dossiers\Textes\Quantiles\Codes\Quantiles_stata\Matbounds_m.txt','Matres_m','-ASCII');
elseif sex==1
save ('C:\Dfile\Dossiers\Textes\Quantiles\Codes\Quantiles_stata\Matbounds_f.txt','Matres_f','-ASCII');
end
