%%%% Matlab code for Arellano and Bonhomme, "Quantile Selection Models"
%%%% This code estimates the copula parameter rho, for a (gender,marital
%%%% status)-cell
%%%% The code makes use of rq.m
%%%% It also use the files vecrho.mat, data_1.out, data_2.out


clear all;
clc;



% values of rho for the grid search
load vecrho.mat


[N col]=size(data);
vecrho1=data(1:N,1);
vecrho2=data(1:N,2);

% load FES data
nbvar=32;

data = csv2mat_numeric('data_1.out');
Vec_m=struct2cell(data);
Vec_m=cell2mat(Vec_m);
[Nvar a]=size(Vec_m);
N=Nvar/nbvar;
Mat_m=Vec_m(1:N);
for j=2:nbvar
    Mat_m=[Mat_m Vec_m((j-1)*N+1:j*N)];
end


data = csv2mat_numeric('data_2.out');
Vec_f=struct2cell(data);
Vec_f=cell2mat(Vec_f);
[Nvar a]=size(Vec_f);
N=Nvar/nbvar;
Mat_f=Vec_f(1:N);
for j=2:nbvar
    Mat_f=[Mat_f Vec_f((j-1)*N+1:j*N)];
end

clear Vec_m Vec_f data 

% Marital status. 
% ma=1 denotes married.
ma=0;

% Loop on gender
% sex=1 denotes female
for sex=0:1

if sex==0    
    Mat=Mat_m;
elseif sex==1
    Mat=Mat_f;
end

% Keep single/married    
[Ntot coltot]=size(Mat);
Mat=Mat((Mat(:,1)==ma),2:coltot);


    
[N col]=size(Mat);
D=Mat(1:N,2);
suppZ=Mat(1:N,4);
X=Mat(1:N,5:col-1);
pZ=Mat(1:N,3);
Year=Mat(1:N,col);

% Keep only working individiduals
Mat1=Mat(D==1,1:col);

[N1 col1]=size(Mat1);

Y1=Mat1(1:N1,1);
pZ1=Mat1(1:N1,3);
suppZ1=Mat1(1:N1,4);
X1=Mat1(1:N1,5:col-1);

% Rescale X (to avoid ill-conditioning)
X1=(X1-ones(N1,1)*mean(X1))./(ones(N1,1)*std(X1));
Year1=Mat1(1:N1,col);
[Nx colx]=size(X1);

% Start grid seatch on rho
vecrhoa=vecrho2;
[s n]=size(vecrhoa);
vectau=(.1:.1:.9)';
[t n]=size(vectau);

object=zeros(s,1);

for j=1:s
    rhoa=vecrhoa(j);
    obj=0;
    for k=1:t
        tau=vectau(k);
        % Frank copula
        G=copulacdf('Frank',[tau*ones(N1,1) pZ1],rhoa)./pZ1;
        % Rotated quantile regression
        beta=rq([ones(N1,1) X1],Y1,G);
        % Concentrated objsctive function
        obj=obj+(mean(pZ1.*((Y1<=beta(1)+X1*beta(2:colx+1))-G)));
        
    end
    object(j)=obj^2;
    j % to keep track of iteration number 
end

% Minimize objective function
[C I]=min(object);
rho=vecrhoa(I);

% Spearman rank correlation (optional)
% copulastat('Frank',rho,'type','Spearman');

% Save results
if sex==0
    rho_m=rho;
    object_m=object;
elseif sex==1
    rho_f=rho;
    object_f=object;
end

end


