%%%% Matlab code for Arellano and Bonhomme, "Quantile Selection Models"
%%%% This code estimates the copula parameters for the generalized Frank.
%%%% Depending on the orientation of the copula there are two choices:
%%%% reversed=0 or 1.
%%%% reversed=0 means that the copula is tau-C(tau,1-p).
%%%% reversed=1 means that the copula is p-C(1-tau,p).
%%%% See appendix in the paper

%%%% The code uses rq.m, data1.out and data2.out

clear all;
clc;



% values of theta and delta
vecrhoa1=(1:2:50)';
vecrhoa2=(.05:.05:.95)';
vecrhoa=[kron(vecrhoa1,ones(19,1)) kron(ones(25,1),vecrhoa2)];
[s n]=size(vecrhoa);

nbvar=32;

data = csv2mat_numeric('data_1.out');
Vec_m=struct2cell(data);
Vec_m=cell2mat(Vec_m);
[Nvar a]=size(Vec_m);
N=Nvar/nbvar;
Mat_m=Vec_m(1:N);
for j=2:nbvar
    Mat_m=[Mat_m Vec_m((j-1)*N+1:j*N)];
end

data = csv2mat_numeric('data_2.out');
Vec_f=struct2cell(data);
Vec_f=cell2mat(Vec_f);
[Nvar a]=size(Vec_f);
N=Nvar/nbvar;
Mat_f=Vec_f(1:N);
for j=2:nbvar
    Mat_f=[Mat_f Vec_f((j-1)*N+1:j*N)];
end

clear Vec_m Vec_f data 

% Loop on gender

ma=0;

for sex=0:0

if sex==0    
    Mat=Mat_m;
elseif sex==1
    Mat=Mat_f;
end

% Keep single/married    
[Ntot coltot]=size(Mat);
Mat=Mat((Mat(:,1)==ma),2:coltot);


    
[N col]=size(Mat);
D=Mat(1:N,2);
suppZ=Mat(1:N,4);
X=Mat(1:N,5:col-1);
pZ=Mat(1:N,3);
Year=Mat(1:N,col);

% Keep only working individiduals
Mat1=Mat(D==1,1:col);

[N1 col1]=size(Mat1);

Y1=Mat1(1:N1,1);
pZ1=Mat1(1:N1,3);
suppZ1=Mat1(1:N1,4);
X1=Mat1(1:N1,5:col-1);

% Rescale X
X1=(X1-ones(N1,1)*mean(X1))./(ones(N1,1)*std(X1));
Year1=Mat1(1:N1,col);
[Nx colx]=size(X1);

% Start loop on theta and delta
vectau=(.1:.1:.9)';
[t n]=size(vectau);

object=zeros(s,1);

tic

for j=1:s
    theta=vecrhoa(j,1);
    delta=vecrhoa(j,2);
    gamma=1-(1-delta).^(theta);
    C=(1-(1-delta)^(theta)).^(-1);
    obj1=0;
    obj2=0;
    for k=1:t
        tau=vectau(k);
        
        % comment if reversed=1
        %u1=ones(N1,1)-(ones(N1,1)-delta*tau*ones(N1,1)).^(theta);
        %v1=ones(N1,1)-(ones(N1,1)-delta*(ones(N1,1)-pZ1)).^(theta);
        
        % comment if reversed=0 
        u1=ones(N1,1)-(ones(N1,1)-delta*(1-tau)*ones(N1,1)).^(theta);
        v1=ones(N1,1)-(ones(N1,1)-delta*pZ1).^(theta);
        
        Cop=1/delta*(ones(N1,1)-(ones(N1,1)-C*u1.*v1).^(1/theta));
        % comment if reversed=0 
        Cop=pZ1-Cop;
        % comment if reversed=1
        %Cop=tau*ones(N1,1)-Cop;
        G=Cop./pZ1;
        
        beta=rq([ones(N1,1) X1],Y1,G);
        obj1=obj1+(mean(pZ1.*((Y1<=beta(1)+X1*beta(2:colx+1))-G)));
        obj2=obj2+(mean((pZ1.^2).*((Y1<=beta(1)+X1*beta(2:colx+1))-G)));
       
        
        
    end
    object(j)=obj1.^2+obj2.^2;
    j
end

toc

[C I]=min(object);
theta=vecrhoa(I,1);
delta=vecrhoa(I,2);

Mat_obj=zeros(19,25);
for jj=1:25
    Mat_obj(:,jj)=object((jj-1)*19+1:jj*19);
end

end


