%%%% Matlab code for Arellano and Bonhomme, "Quantile Selection Models"
%%%% This code plots the contours if the estimated generalized Frank copulas, see
%%%% Figure 3 in the paper
%%%% The copula parameters are estimated using Estimation_rho_GeneralizedFrank

%%%% To use the code, uncomment one of the four "optimal" sections (three rows each)
%%%% As an example, the code here plots the contour corresponding to single
%%%% males


clear 
clc;

vecu=(.001:.001:.999)';
vecv=(.001:.001:.999)';

% reversed=0 means that the copula is tau-C(tau,1-p).
% reversed=1 means that the copula is p-C(1-tau,p).
% see appendix in the paper

% males, singles 
% not optimal
%reversed=0;
%theta=11;
%delta=.65;
%optimal
reversed=1;
theta=15;
delta=.45;

% males, married
% optimal
% reversed=0;
% theta=27;
% delta=.05;
% not optimal
%reversed=1;
%theta=27;
%delta=.05;

% females, singles
% not optimal
%reversed=0;
%theta=7;
%delta=.10;
% optimal
%reversed=1;
%theta=13;
%delta=.05;

% females, married
% optimal
%reversed=0;
%theta=3;
%delta=.15;
% non-optimal
%reversed=1;
%theta=7;
%delta=.05;

gamma=1-(1-delta).^(theta);

u1=ones(999,999)-(ones(999,999)-delta*vecu*ones(1,999)).^(theta);
v1=ones(999,999)-(ones(999,999)-delta*ones(999,1)*vecv').^(theta);

C=(1-(1-delta)^(theta)).^(-1);

vecBB8=1/delta*(ones(999,999)-(ones(999,999)-C*u1.*v1).^(1/theta));

vecBB8=vecu*ones(1,999)-vecBB8;

vecderBB8=vecBB8(2:999,2:999)-vecBB8(2:999,1:998)-vecBB8(1:998,2:999)+vecBB8(1:998,1:998);

if reversed==0
x=icdf('normal',vecu(1:998),0,1);
y=icdf('normal',ones(998,1)-vecv(1:998),0,1);
elseif reversed==1
x=icdf('normal',ones(998,1)-vecu(1:998),0,1);
y=icdf('normal',vecv(1:998),0,1);
end

vecderBB8=vecderBB8.*pdf('normal',x*ones(1,998),0,1).*pdf('normal',ones(998,1)*y',0,1);

contour(x,y,-vecderBB8,4);
