%%%% Matlab code for Arellano and Bonhomme, "Quantile Selection Models"
%%%% This code performs subsampling for the parameters of the Frank copula 
%%%% The data is slightly different as the propensity score is re-estimated
%%%% in each subsample.
%%%% The code uses datasub_1.out and datasub_2.out, vecrho, and rq.m

clear all;
clc;

% values of rho

load vecrho.mat

[N col]=size(data);
vecrho1=data(1:N,1);
vecrho2=data(1:N,2);

nbvar=32;

data = csv2mat_numeric('datasub_1.out');
Vec_m=struct2cell(data);
Vec_m=cell2mat(Vec_m);
[Nvar a]=size(Vec_m);
N=Nvar/nbvar;
Mat_m=Vec_m(1:N);
for j=2:nbvar
    Mat_m=[Mat_m Vec_m((j-1)*N+1:j*N)];
end
Nm=N;

data = csv2mat_numeric('datasub_2.out');
Vec_f=struct2cell(data);
Vec_f=cell2mat(Vec_f);
[Nvar a]=size(Vec_f);
N=Nvar/nbvar;
Mat_f=Vec_f(1:N);
for j=2:nbvar
    Mat_f=[Mat_f Vec_f((j-1)*N+1:j*N)];
end
Nf=N;

clear Vec_m Vec_f data 


Mat_m0=Mat_m;
Mat_f0=Mat_f;

% marital status
ma=0;


% Subsample sizes (by gender)
if ma==1
    bbm=floor(2000+sqrt(Nm));
    bbf=floor(2000+sqrt(Nf));
elseif ma==0
    bbm=floor(4000+sqrt(Nm));
    bbf=floor(4000+sqrt(Nf));
end

Nsub=200;
Res_rho=zeros(Nsub,1);
for jsub=1:Nsub

% Extract subsamples
UUm=floor(rand(bbm,1)*Nm)+1;
UUf=floor(rand(bbf,1)*Nf)+1;

Mat_m=Mat_m0(UUm,:);
Mat_f=Mat_f0(UUf,:);

% Loop on gender


for sex=0:0

if sex==0    
    Mat=Mat_m;
elseif sex==1
    Mat=Mat_f;
end

% Keep single/married    
[Ntot coltot]=size(Mat);
Mat=Mat((Mat(:,1)==ma),2:coltot);


    
[N col]=size(Mat);
D=Mat(1:N,2);
Z_m=Mat(1:N,3);
Z_s=Mat(1:N,4);
X=Mat(1:N,5:col-1);
Year=Mat(1:N,col);

if ma==1
    Z=Z_m;
elseif ma==0
    Z=Z_s;
end

% Probit for participation
XZ0=[Z X];
%XZ0=(XZ0-ones(N,1)*mean(XZ0))./(ones(N,1)*std(XZ0));
XZ0=(XZ0-ones(N,1)*mean(XZ0));
XZ=[ones(N,1) XZ0];
[a colxz]=size(XZ);
par0=zeros(colxz,1);
par = fminunc(@(par) -sum(D.*log(normcdf(XZ*par))+(1-D).*log(normcdf(-XZ*par))),par0);

pZ=normcdf(XZ*par);

% Keep only working individiduals
Mat1=Mat(D==1,1:col);

[N1 col1]=size(Mat1);

Y1=Mat1(1:N1,1);
pZ1=pZ(D==1,1);
X1=Mat1(1:N1,5:col-1);

% Rescale X
X1=(X1-ones(N1,1)*mean(X1))./(ones(N1,1)*std(X1));
Year1=Mat1(1:N1,col);
[Nx colx]=size(X1);

% Start loop on rho
vecrhoa=vecrho2;
[s n]=size(vecrhoa);
%vectau=(.10:.1:.90)';
vectau=(.1:.1:.9)';
[t n]=size(vectau);

object=zeros(s,1);

tic

for j=1:s
    rhoa=vecrhoa(j);
    obj=0;
    for k=1:t
        tau=vectau(k);
        G=copulacdf('Frank',[tau*ones(N1,1) pZ1],rhoa)./pZ1;
        beta=rq([ones(N1,1) X1],Y1,G);
        %obj=obj+(sqrt(tau*(1-tau))*mean(pZ1.*((Y1<=beta(1)+X1*beta(2:colx+1))-G)));
        %drhoG=-1/1*G-(1./(1*pZ1*(1-exp(-1))).*(1*exp(-1)*(1-exp(-1*tau)).*(1-exp(-1*pZ1))-(1-exp(-1))*(tau*exp(-1*tau)*(1-exp(-1*pZ1))+pZ1.*(1-exp(-1*tau)).*exp(-1*pZ1)))./((1-exp(-1))-(1-exp(-1*tau)).*(1-exp(-1*pZ1))));
        
        %obj=obj+(mean(drhoG.*((Y1<=beta(1)+X1*beta(2:colx+1))-G)));
        %obj=obj+(mean(sqrt(tau*(1-tau))*pZ1.*((Y1<=beta(1)+X1*beta(2:colx+1))-G)));
        obj=obj+(mean(pZ1.*((Y1<=beta(1)+X1*beta(2:colx+1))-G)));
    end
    object(j)=obj^2;
    j
end

toc

[C I]=min(object);
rho=vecrhoa(I);

copulastat('Frank',rho,'type','Spearman');

if sex==0
    rho_m=rho;
    object_m=object;
elseif sex==1
    rho_f=rho;
    object_f=object;
end

end

Res_rho(jsub,1)=rho;
end

% Compute confidence intervals 
% The rho values are the full-sample estimates
if sex==0
    Mat=Mat_m0;
    bb=bbm;
    if ma==1
        rho=-1.482;
    elseif ma==0
        rho=-7.638;
    end
    
elseif sex==1
    Mat=Mat_f0;
    bb=bbf;
    if ma==1
        rho=-1.035;
    elseif ma==0
        rho=-.482;
    end    
end

Ntot=sum(Mat(:,1)==ma);

upper=quantile(sqrt(N)*(Res_rho-rho),.975);
lower=quantile(sqrt(N)*(Res_rho-rho),.025);

[rho+lower/sqrt(Ntot) rho+upper/sqrt(Ntot)]

Res_corr=zeros(Nsub,1);
for jsub=1:Nsub
    Res_corr(jsub,1)=copulastat('Frank',Res_rho(jsub,1),'type','Spearman');
end

corr=copulastat('Frank',rho,'type','Spearman');

upper_corr=quantile(sqrt(N)*(Res_corr-corr),.975);
lower_corr=quantile(sqrt(N)*(Res_corr-corr),.025);

[corr+lower_corr/sqrt(Ntot) corr+upper_corr/sqrt(Ntot)]


