/* Stata code for Arellano and Bonhomme, "Quantile Selection Models" */
/* This code produces 6,7,8 and I1-I2 in the appendix */
/* It takes as input Matresults.txt */


clear matrix

set matsize 400
set trace off
set seed 2
clear
set mem 500m
set more 1

cd C:\Dfile\Dossiers\Textes\Quantiles\Codes\Quantiles_stata

** first clean up raw data
infile year gender ed18 work lw D_orig D_PE D_GE Ystar_PE Ystar_GE using "C:\Dfile\Dossiers\Textes\Quantiles\Codes\Quantiles_stata\Matresults.txt", clear


*rename col1 year
*rename col2 gender
*rename col3 ed18
*rename col4 work
*rename col5 lw
*rename col6 D_orig
*rename col7 D_PE
*rename col8 D_GE
*rename col9 Ystar_PE
*rename col10 Ystar_GE

replace lw=. if lw<-100


gen var_year=_n+77 if _n<=23


gen quantlw10_0=.
gen quantlw50_0=.
gen quantlw90_0=.
gen quantlw10_1=.
gen quantlw50_1=.
gen quantlw90_1=.
local j=78
while `j'<=100{
_pctile lw if year==`j' & gender==0, p(10 50 90)
replace quantlw10_0=r(r1) if var_year==`j'
replace quantlw50_0=r(r2) if var_year==`j'
replace quantlw90_0=r(r3) if var_year==`j'
_pctile lw if year==`j' & gender==1, p(10 50 90)
replace quantlw10_1=r(r1) if var_year==`j'
replace quantlw50_1=r(r2) if var_year==`j'
replace quantlw90_1=r(r3) if var_year==`j'
local j=`j'+1
}



* fit
gen quantlw10_fit_0=.
gen quantlw50_fit_0=.
gen quantlw90_fit_0=.
gen quantlw10_fit_1=.
gen quantlw50_fit_1=.
gen quantlw90_fit_1=.
local j=78
while `j'<=100{
_pctile Ystar_PE if D_orig==1 & year==`j' & gender==0, p(10 50 90)
replace quantlw10_fit_0=r(r1) if var_year==`j'
replace quantlw50_fit_0=r(r2) if var_year==`j'
replace quantlw90_fit_0=r(r3) if var_year==`j'
_pctile Ystar_PE if D_orig==1 & year==`j' & gender==1, p(10 50 90)
replace quantlw10_fit_1=r(r1) if var_year==`j'
replace quantlw50_fit_1=r(r2) if var_year==`j'
replace quantlw90_fit_1=r(r3) if var_year==`j'
local j=`j'+1
}

* partial equilibrium
gen quantlw10_PE_pot_0=.
gen quantlw50_PE_pot_0=.
gen quantlw90_PE_pot_0=.
gen quantlw10_PE_pot_1=.
gen quantlw50_PE_pot_1=.
gen quantlw90_PE_pot_1=.
local j=78
while `j'<=100{
_pctile Ystar_PE if year==`j' & gender==0, p(10 50 90)
replace quantlw10_PE_pot_0=r(r1) if var_year==`j'
replace quantlw50_PE_pot_0=r(r2) if var_year==`j'
replace quantlw90_PE_pot_0=r(r3) if var_year==`j'
_pctile Ystar_PE if year==`j' & gender==1, p(10 50 90)
replace quantlw10_PE_pot_1=r(r1) if var_year==`j'
replace quantlw50_PE_pot_1=r(r2) if var_year==`j'
replace quantlw90_PE_pot_1=r(r3) if var_year==`j'
local j=`j'+1
}


* general equilibrium
gen quantlw10_GE_pot_0=.
gen quantlw50_GE_pot_0=.
gen quantlw90_GE_pot_0=.
gen quantlw10_GE_pot_1=.
gen quantlw50_GE_pot_1=.
gen quantlw90_GE_pot_1=.
local j=78
while `j'<=100{
_pctile Ystar_GE if year==`j' & gender==0, p(10 50 90)
replace quantlw10_GE_pot_0=r(r1) if var_year==`j'
replace quantlw50_GE_pot_0=r(r2) if var_year==`j'
replace quantlw90_GE_pot_0=r(r3) if var_year==`j'
_pctile Ystar_GE if year==`j'  & gender==1, p(10 50 90)
replace quantlw10_GE_pot_1=r(r1) if var_year==`j'
replace quantlw50_GE_pot_1=r(r2) if var_year==`j'
replace quantlw90_GE_pot_1=r(r3) if var_year==`j'
local j=`j'+1
}

* employment: data
gen emp_0=.
gen emp_1=.
local j=78
while `j'<=100{
su work if year==`j' & gender==0
replace emp_0=r(mean) if var_year==`j'
su work if year==`j' & gender==1
replace emp_1=r(mean) if var_year==`j'
local j=`j'+1
}


* employment: fitted values
gen emp_fit_0=.
gen emp_fit_1=.
local j=78
while `j'<=100{
su D_orig if year==`j' & gender==0
replace emp_fit_0=r(mean) if var_year==`j'
su D_orig if year==`j' & gender==1
replace emp_fit_1=r(mean) if var_year==`j'
local j=`j'+1
}


* employment: partial equilibrium
gen emp_PE_0=.
gen emp_PE_1=.
local j=78
while `j'<=100{
su D_PE if year==`j' & gender==0
replace emp_PE_0=r(mean) if var_year==`j'
su D_PE if year==`j' & gender==1
replace emp_PE_1=r(mean) if var_year==`j'
local j=`j'+1
}

* employment: general equilibrium
gen emp_GE_0=.
gen emp_GE_1=.
local j=78
while `j'<=100{
su D_GE if year==`j' & gender==0
replace emp_GE_0=r(mean) if var_year==`j'
su D_GE if year==`j' & gender==1
replace emp_GE_1=r(mean) if var_year==`j'
local j=`j'+1
}

* counterfactual: partial equilibrium
gen quantlw10_PE_0=.
gen quantlw50_PE_0=.
gen quantlw90_PE_0=.
gen quantlw10_PE_1=.
gen quantlw50_PE_1=.
gen quantlw90_PE_1=.
local j=78
while `j'<=100{
_pctile Ystar_PE if year==`j' & D_PE==1 & gender==0, p(10 50 90)
replace quantlw10_PE_0=r(r1) if var_year==`j'
replace quantlw50_PE_0=r(r2) if var_year==`j'
replace quantlw90_PE_0=r(r3) if var_year==`j'
_pctile Ystar_PE if year==`j' & D_PE==1 & gender==1, p(10 50 90)
replace quantlw10_PE_1=r(r1) if var_year==`j'
replace quantlw50_PE_1=r(r2) if var_year==`j'
replace quantlw90_PE_1=r(r3) if var_year==`j'
local j=`j'+1
}


* counterfactual: general equilibrium
gen quantlw10_GE_0=.
gen quantlw50_GE_0=.
gen quantlw90_GE_0=.
gen quantlw10_GE_1=.
gen quantlw50_GE_1=.
gen quantlw90_GE_1=.
local j=78
while `j'<=100{
_pctile Ystar_GE if year==`j' & D_GE==1 & gender==0, p(10 50 90)
replace quantlw10_GE_0=r(r1) if var_year==`j'
replace quantlw50_GE_0=r(r2) if var_year==`j'
replace quantlw90_GE_0=r(r3) if var_year==`j'
_pctile Ystar_GE if year==`j' & D_GE==1  & gender==1, p(10 50 90)
replace quantlw10_GE_1=r(r1) if var_year==`j'
replace quantlw50_GE_1=r(r2) if var_year==`j'
replace quantlw90_GE_1=r(r3) if var_year==`j'
local j=`j'+1
}



replace var_year=var_year+1900

twoway scatter quantlw10_0 quantlw10_PE_pot_0 quantlw10_GE_pot_0 quantlw10_1 quantlw10_PE_pot_1 quantlw10_GE_pot_1 var_year if var_year<=2000, /*
*/ c(l l l l l l) ms(p p p p p p) lwidth(medthick medthick medthick thin thin thin) /*
*/ lpattern(solid dash dot solid dash dot) legend(off) xtitle("year") ytitle("log wage")

twoway scatter quantlw50_0 quantlw50_PE_pot_0 quantlw50_GE_pot_0 quantlw50_1 quantlw50_PE_pot_1 quantlw50_GE_pot_1 var_year if var_year<=2000, /*
*/ c(l l l l l l) ms(p p p p p p) lwidth(medthick medthick medthick thin thin thin) /*
*/ lpattern(solid dash dot solid dash dot) legend(off) xtitle("year") ytitle("log wage")

twoway scatter quantlw90_0 quantlw90_PE_pot_0 quantlw90_GE_pot_0 quantlw90_1 quantlw90_PE_pot_1 quantlw90_GE_pot_1 var_year if var_year<=2000, /*
*/ c(l l l l l l) ms(p p p p p p) lwidth(medthick medthick medthick thin thin thin) /*
*/ lpattern(solid dash dot solid dash dot) legend(off) xtitle("year") ytitle("log wage")

twoway scatter emp_0 emp_fit_0 emp_PE_0 emp_GE_0 emp_1 emp_fit_1 emp_PE_1 emp_GE_1 var_year if var_year<=2000, /*
*/ c(l l l l l l l l) ms(p t p p p t p p) lwidth(medthick medthick medthick medthick thin thin thin thin) /*
*/ lpattern(solid solid dash dot solid solid dash dot) legend(off) xtitle("year") ytitle("log wage")

twoway scatter quantlw10_0 quantlw10_fit_0 quantlw10_PE_pot_0 quantlw10_GE_pot_0 quantlw10_1 quantlw10_fit_1 quantlw10_PE_pot_1 quantlw10_GE_pot_1 var_year if var_year<=2000, /*
*/ c(l l l l l l l l) ms(p t p p p t p p) lwidth(medthick medthick medthick medthick thin thin thin thin) /*
*/ lpattern(solid solid dash dot solid solid dash dot) legend(off) xtitle("year") ytitle("log wage")

twoway scatter quantlw50_0 quantlw50_fit_0 quantlw50_PE_pot_0 quantlw50_GE_pot_0 quantlw50_1 quantlw50_fit_1 quantlw50_PE_pot_1 quantlw50_GE_pot_1 var_year if var_year<=2000, /*
*/ c(l l l l l l l l) ms(p t p p p t p p) lwidth(medthick medthick medthick medthick thin thin thin thin) /*
*/ lpattern(solid solid dash dot solid solid dash dot) legend(off) xtitle("year") ytitle("log wage")

* Fit: wages

twoway scatter quantlw10_0 quantlw10_fit_0 quantlw10_1 quantlw10_fit_1 var_year if var_year<=2000, /*
*/ c(l l l l) ms(p p p p) lwidth(thick thick medthick medthick) /*
*/ lpattern(solid dash solid dash) legend(off) xtitle("year",size(large)) ytitle("log wage",size(large))
graph export "C:\Dfile\Dossiers\Quantiles\GEfig_fit10.eps", as(eps) preview(off) replace


twoway scatter quantlw50_0 quantlw50_fit_0 quantlw50_1 quantlw50_fit_1 var_year if var_year<=2000, /*
*/ c(l l l l) ms(p p p p) lwidth(thick thick medthick medthick) /*
*/ lpattern(solid dash solid dash) legend(off) xtitle("year",size(large)) ytitle("log wage",size(large))
graph export "C:\Dfile\Dossiers\Quantiles\GEfig_fit50.eps", as(eps) preview(off) replace

twoway scatter quantlw90_0 quantlw90_fit_0 quantlw90_1 quantlw90_fit_1 var_year if var_year<=2000, /*
*/ c(l l l l) ms(p p p p) lwidth(thick thick medthick medthick) /*
*/ lpattern(solid dash solid dash) legend(off) xtitle("year",size(large)) ytitle("log wage",size(large))
graph export "C:\Dfile\Dossiers\Quantiles\GEfig_fit90.eps", as(eps) preview(off) replace

* Fit: employment

twoway scatter emp_0 emp_fit_0 emp_1 emp_fit_1 var_year if var_year<=2000, /*
*/ c(l l l l) ms(p p p p) lwidth(thick thick medthick medthick) /*
*/ lpattern(solid dash solid dash) legend(off) xtitle("year",size(large)) ytitle("employment rate",size(large))
graph export "C:\Dfile\Dossiers\Quantiles\GEfig_fitemp.eps", as(eps) preview(off) replace

* Wages

twoway scatter quantlw10_fit_0 quantlw10_PE_pot_0 quantlw10_GE_pot_0 quantlw10_fit_1 quantlw10_PE_pot_1 quantlw10_GE_pot_1 var_year if var_year<=2000, /*
*/ c(l l l l l l) ms(p p p p p p) lwidth(thick thick thick medthick medthick medthick) /*
*/ lpattern(solid dash dot solid dash dot) legend(off) xtitle("year",size(large)) ytitle("log wage",size(large))
*graph export "C:\Dfile\Dossiers\Quantiles\GEfig_10.eps", as(eps) preview(off) replace

twoway scatter quantlw50_fit_0 quantlw50_PE_pot_0 quantlw50_GE_pot_0 quantlw50_fit_1 quantlw50_PE_pot_1 quantlw50_GE_pot_1 var_year if var_year<=2000, /*
*/ c(l l l l l l) ms(p p p p p p) lwidth(thick thick thick medthick medthick medthick) /*
*/ lpattern(solid dash dot solid dash dot) legend(off) xtitle("year",size(large)) ytitle("log wage",size(large))
*graph export "C:\Dfile\Dossiers\Quantiles\GEfig_50.eps", as(eps) preview(off) replace

twoway scatter quantlw90_fit_0 quantlw90_PE_pot_0 quantlw90_GE_pot_0 quantlw90_fit_1 quantlw90_PE_pot_1 quantlw90_GE_pot_1 var_year if var_year<=2000, /*
*/ c(l l l l l l) ms(p p p p p p) lwidth(thick thick thick medthick medthick medthick) /*
*/ lpattern(solid dash dot solid dash dot) legend(off) xtitle("year",size(large)) ytitle("log wage",size(large))
*graph export "C:\Dfile\Dossiers\Quantiles\GEfig_90.eps", as(eps) preview(off) replace

* Wages (latent)

twoway scatter quantlw10_PE_pot_0 quantlw10_GE_pot_0 quantlw10_PE_pot_1 quantlw10_GE_pot_1 var_year if var_year<=2000, /*
*/ c(l l l l) ms(p p p p) lwidth(thick thick medthick medthick) /*
*/ lpattern(solid dash solid dash) legend(off) xtitle("year",size(large)) ytitle("log wage",size(large))
graph export "C:\Dfile\Dossiers\Quantiles\GEfig_10.eps", as(eps) preview(off) replace

twoway scatter quantlw50_PE_pot_0 quantlw50_GE_pot_0 quantlw50_PE_pot_1 quantlw50_GE_pot_1 var_year if var_year<=2000, /*
*/ c(l l l l) ms(p p p p) lwidth(thick thick medthick medthick) /*
*/ lpattern(solid dash solid dash) legend(off) xtitle("year",size(large)) ytitle("log wage",size(large))
graph export "C:\Dfile\Dossiers\Quantiles\GEfig_50.eps", as(eps) preview(off) replace

twoway scatter quantlw90_PE_pot_0 quantlw90_GE_pot_0 quantlw90_PE_pot_1 quantlw90_GE_pot_1 var_year if var_year<=2000, /*
*/ c(l l l l) ms(p p p p) lwidth(thick thick medthick medthick) /*
*/ lpattern(solid dash solid dash) legend(off) xtitle("year",size(large)) ytitle("log wage",size(large))
graph export "C:\Dfile\Dossiers\Quantiles\GEfig_90.eps", as(eps) preview(off) replace


* Employment
twoway scatter emp_fit_0 emp_PE_0 emp_GE_0 emp_fit_1 emp_PE_1 emp_GE_1 var_year if var_year<=2000, /*
*/ c(l l l l l l) ms(p p p p p p) lwidth(thick thick thick medthick medthick medthick) /*
*/ lpattern(solid dash dot solid dash dot) legend(off) xtitle("year",size(large)) ytitle("employment rate",size(large))
graph export "C:\Dfile\Dossiers\Quantiles\GEfig_emp.eps", as(eps) preview(off) replace


* Wages (counterfactual)

twoway scatter quantlw10_fit_0 quantlw10_PE_0 quantlw10_GE_0 quantlw10_fit_1 quantlw10_PE_1 quantlw10_GE_1 var_year if var_year<=2000, /*
*/ c(l l l l l l) ms(p p p p p p) lwidth(thick thick thick medthick medthick medthick) /*
*/ lpattern(solid dash dot solid dash dot) legend(off) xtitle("year",size(large)) ytitle("log wage",size(large))
graph export "C:\Dfile\Dossiers\Quantiles\GEfigc_10.eps", as(eps) preview(off) replace

twoway scatter quantlw50_fit_0 quantlw50_PE_0 quantlw50_GE_0 quantlw50_fit_1 quantlw50_PE_1 quantlw50_GE_1 var_year if var_year<=2000, /*
*/ c(l l l l l l) ms(p p p p p p) lwidth(thick thick thick medthick medthick medthick) /*
*/ lpattern(solid dash dot solid dash dot) legend(off) xtitle("year",size(large)) ytitle("log wage",size(large))
graph export "C:\Dfile\Dossiers\Quantiles\GEfigc_50.eps", as(eps) preview(off) replace

twoway scatter quantlw90_fit_0 quantlw90_PE_0 quantlw90_GE_0 quantlw90_fit_1 quantlw90_PE_1 quantlw90_GE_1 var_year if var_year<=2000, /*
*/ c(l l l l l l) ms(p p p p p p) lwidth(thick thick thick medthick medthick medthick) /*
*/ lpattern(solid dash dot solid dash dot) legend(off) xtitle("year",size(large)) ytitle("log wage",size(large))
graph export "C:\Dfile\Dossiers\Quantiles\GEfigc_90.eps", as(eps) preview(off) replace

