/* Stata code for Arellano and Bonhomme, "Quantile Selection Models" */
/* This code draws bounds on latent quantiles, by gender. See the top and middle panels in Figure 5 in the paper. */
/* The code takes as inputs Matbounds_m.txt and Matbounds_f.txt, which are produced by Estimation_beta_bounds.m */ 
/* There are two specifications: trimmed, and un-trimmed */

set matsize 400
set trace off
set seed 2
clear
clear matrix
set mem 500m
set more 1

cd C:\Dfile\Dossiers\Textes\Quantiles\Codes\Quantiles_stata

set obs 23
gen var_year=_n+1977
sort var_year
save results_graphs_q.dta, replace



infile lw_low lw_up year a b c using "C:\Dfile\Dossiers\Textes\Quantiles\Codes\Quantiles_stata\Matbounds_m.txt", clear 

gen var_year=_n+1977

local k=10
while `k'<=90{
gen varlow_m_q`k'=.
gen varup_m_q`k'=.
local k=`k'+10
}

local j=78
while `j'<=100{
_pctile lw_low if year==`j', p(10 20 30 40 50 60 70 80 90)
local k=10
while `k'<=90{
local l=`k'/10
replace varlow_m_q`k'=r(r`l') if var_year==1900+`j'
local k=`k'+10
}
local j=`j'+1
}

local j=78
while `j'<=100{
_pctile lw_up if year==`j', p(10 20 30 40 50 60 70 80 90)
local k=10
while `k'<=90{
local l=`k'/10
replace varup_m_q`k'=r(r`l') if var_year==1900+`j'
local k=`k'+10
}
local j=`j'+1
}


* save results
keep var_year varlow_m* varup_m*
sort var_year 
merge using results_graphs_q.dta
drop _merge

save results_graphs_q.dta, replace


infile lw_low lw_up year a b c using "C:\Dfile\Dossiers\Textes\Quantiles\Codes\Quantiles_stata\Matbounds_f.txt", clear 

gen var_year=_n+1977

local k=10
while `k'<=90{
gen varlow_f_q`k'=.
gen varup_f_q`k'=.
local k=`k'+10
}

local j=78
while `j'<=100{
_pctile lw_low if year==`j', p(10 20 30 40 50 60 70 80 90)
local k=10
while `k'<=90{
local l=`k'/10
replace varlow_f_q`k'=r(r`l') if var_year==1900+`j'
local k=`k'+10
}
local j=`j'+1
}

local j=78
while `j'<=100{
_pctile lw_up if year==`j', p(10 20 30 40 50 60 70 80 90)
local k=10
while `k'<=90{
local l=`k'/10
replace varup_f_q`k'=r(r`l') if var_year==1900+`j'
local k=`k'+10
}
local j=`j'+1
}


* save results
keep var_year varlow_f* varup_f*
sort var_year 
merge using results_graphs_q.dta
drop _merge

save results_graphs_q.dta, replace



* loop on gender
local gender=1
while `gender'<=2{


u data_`gender', clear

gen var_year=_n+1977

local k=10
while `k'<=90{
gen var_`gender'_q`k'_nosel=.
local k=`k'+10
}

local j=78
while `j'<=100{
_pctile lw if year==`j', p(10 20 30 40 50 60 70 80 90)
local k=10
while `k'<=90{
local l=`k'/10
replace var_`gender'_q`k'_nosel=r(r`l') if var_year==1900+`j'
local k=`k'+10
}
local j=`j'+1
}

* save results
keep var_year var_`gender'*
sort var_year 
merge using results_graphs_q.dta
drop _merge

save results_graphs_q.dta, replace




local gender=`gender'+1
}



* graphs
use results_graphs_q.dta, clear
local k=10
while `k'<=90{
twoway scatter varlow_m_q`k' varup_m_q`k' var_1_q`k'_nosel varlow_f_q`k' varup_f_q`k' var_2_q`k'_nosel var_year if var_year<=2000, /*
*/ c(l l l l l l) ms(p p p p p p) lwidth(thick thick thick medthick medthick medthick) lpattern(dash dash solid dash dash solid) legend(off) xtitle("year",size(large)) ytitle("log wage",size(large))
* comment if using un-trimmed estimator
graph export "C:\Dfile\Dossiers\Textes\Quantiles\Codes\Quantiles_stata\figbounds`k'.eps", as(eps) preview(off) replace
* comment if using trimmed estimator
*graph export "C:\Dfile\Dossiers\Textes\Quantiles\Codes\Quantiles_stata\figbounds2`k'.eps", as(eps) preview(off) replace
sleep 10000 
local k=`k'+10
}

