/* Stata code for Arellano and Bonhomme, "Quantile Selection Models" */
/* This code draws bounds on latent quantiles, by education. See the bottom panel in Figure 5 in the paper. */
/* The code takes as input Matbounds_m.txt, which is produced by Estimation_beta_bounds.m */ 
/* The specification in the paper is the trimmed one */

** Note: results are sensitive to simulation error (as samples conditional on gender and education are small)
** Hence the final results may differ somewhat from the ones in the paper


set matsize 400
set trace off
set seed 2
clear
clear matrix
set mem 500m
set more 1

cd C:\Dfile\Dossiers\Textes\Quantiles\Codes\Quantiles_stata

set obs 23
gen var_year=_n+1977
sort var_year
save results_graphs_q.dta, replace


infile lw_low lw_up year ed17 ed18 work using "C:\Dfile\Dossiers\Textes\Quantiles\Codes\Quantiles_stata\Matbounds_m.txt", clear 
save data_inter, replace
*infile lw_low lw_up year ed17 ed18 work using "C:\Dfile\Dossiers\Textes\Quantiles\Codes\Quantiles_stata\Matbounds_f.txt", clear 
*append using data_inter
*save data_inter, replace


gen ed=ed17+ed18

* LESS EDUCATED MALES

gen var_year=_n+1977

local k=10
while `k'<=90{
gen varlow_m_q`k'=.
gen varup_m_q`k'=.
local k=`k'+10
}

local j=78
while `j'<=100{
_pctile lw_low if year==`j' & ed==0, p(10 20 30 40 50 60 70 80 90)
 
local k=10
while `k'<=90{
local l=`k'/10
replace varlow_m_q`k'=r(r`l') if var_year==1900+`j'
local k=`k'+10
}
local j=`j'+1
}

local j=78
while `j'<=100{
_pctile lw_up if year==`j' & ed==0, p(10 20 30 40 50 60 70 80 90)
local k=10
while `k'<=90{
local l=`k'/10
replace varup_m_q`k'=r(r`l') if var_year==1900+`j'
local k=`k'+10
}
local j=`j'+1
}


* save results
keep var_year varlow_m* varup_m*
sort var_year 
merge using results_graphs_q.dta
drop _merge

save results_graphs_q.dta, replace

* MORE EDUCATED

use data_inter, clear

gen ed=ed17+ed18

gen var_year=_n+1977

local k=10
while `k'<=90{
gen varlow_f_q`k'=.
gen varup_f_q`k'=.
local k=`k'+10
}

local j=78
while `j'<=100{
_pctile lw_low if year==`j' & ed==1, p(10 20 30 40 50 60 70 80 90)
local k=10
while `k'<=90{
local l=`k'/10
replace varlow_f_q`k'=r(r`l') if var_year==1900+`j'
local k=`k'+10
}
local j=`j'+1
}

local j=78
while `j'<=100{
_pctile lw_up if year==`j' & ed==1, p(10 20 30 40 50 60 70 80 90)
local k=10
while `k'<=90{
local l=`k'/10
replace varup_f_q`k'=r(r`l') if var_year==1900+`j'
local k=`k'+10
}
local j=`j'+1
}


* save results
keep var_year varlow_f* varup_f*
sort var_year 
merge using results_graphs_q.dta
drop _merge

save results_graphs_q.dta, replace



* OBSERVED WAGES

* loop on education

local educ=0
while `educ'<=1{

u data_1, clear
save data_inter, replace
*u data_2, clear
*append using data_inter
*save data_inter, replace


gen ed=ed17+ed18

gen var_year=_n+1977


local k=10
while `k'<=90{
gen var_`educ'_q`k'_nosel=.
local k=`k'+10
}

local j=78
while `j'<=100{
if `educ'==0{
_pctile lw if year==`j' & ed==0, p(10 20 30 40 50 60 70 80 90)
}
if `educ'==1{
_pctile lw if year==`j' & ed==1, p(10 20 30 40 50 60 70 80 90)
}
local k=10
while `k'<=90{
local l=`k'/10
replace var_`educ'_q`k'_nosel=r(r`l') if var_year==1900+`j'
local k=`k'+10
}
local j=`j'+1
}

* save results
keep var_year var_`educ'*
sort var_year 
merge using results_graphs_q.dta
drop _merge

save results_graphs_q.dta, replace




local educ=`educ'+1
}



* graphs
use results_graphs_q.dta, clear
local k=10
while `k'<=90{
twoway scatter varlow_f_q`k' varup_f_q`k' var_1_q`k'_nosel varlow_m_q`k' varup_m_q`k' var_0_q`k'_nosel var_year if var_year<=2000, /*
*/ c(l l l l l l) ms(p p p p p p) lwidth(thick thick thick medthick medthick medthick) lpattern(dash dash solid dash dash solid) legend(off) xtitle("year") ytitle("log wage")
graph export "C:\Dfile\Dossiers\Quantiles\figbounds`k'_educ.eps", as(eps) preview(off) replace
sleep 10000 
local k=`k'+10
}

