/* Stata code for Arellano and Bonhomme, "Quantile Selection Models" */
/* This codes draws the quantiles of latent outcomes. See Figure 1 in the paper. */
/* The main specification is based on Matres_m and Matres_f, obtained by running Estimation_beta */ 
/* When uncommenting some lines in the code, results produce Figure 4 in the paper based on the generalized Frank copula */

/* There may be minor differences compared to the figures in the paper, due to simulation error */

set matsize 400
set trace off
set seed 2
clear
clear matrix
set mem 500m
set more 1

cd C:\Dfile\Dossiers\Textes\Quantiles\Codes\Quantiles_stata

set obs 23
gen var_year=_n+1977
sort var_year
save results_graphs_q.dta, replace

* uncomment if baseline results
infile lw year a b c using "C:\Dfile\Dossiers\Textes\Quantiles\Codes\Quantiles_stata\Matres_m.txt", clear 

* uncomment if bb8 (generalized Frank) copula
* infile lw year a b c using "C:\Dfile\Dossiers\Textes\Quantiles\Codes\Quantiles_stata\Matbb8_m.txt", clear 

gen var_year=_n+1977

local k=10
while `k'<=90{
gen var_m_q`k'=.
local k=`k'+10
}

local j=78
while `j'<=100{
_pctile lw if year==`j', p(10 20 30 40 50 60 70 80 90)
local k=10
while `k'<=90{
local l=`k'/10
replace var_m_q`k'=r(r`l') if var_year==1900+`j'
local k=`k'+10
}
local j=`j'+1
}

* save results
keep var_year var_m*
sort var_year 
merge using results_graphs_q.dta
drop _merge

save results_graphs_q.dta, replace

* uncomment if baseline results
infile lw year a b c using "C:\Dfile\Dossiers\Textes\Quantiles\Codes\Quantiles_stata\Matres_f.txt", clear 

* uncomment if bb8 copula
*infile lw year a b c using "C:\Dfile\Dossiers\Textes\Quantiles\Codes\Quantiles_stata\Matbb8_f.txt", clear 

gen var_year=_n+1977

local k=10
while `k'<=90{
gen var_f_q`k'=.
local k=`k'+10
}

local j=78
while `j'<=100{
_pctile lw if year==`j', p(10 20 30 40 50 60 70 80 90)
local k=10
while `k'<=90{
local l=`k'/10
replace var_f_q`k'=r(r`l') if var_year==1900+`j'
local k=`k'+10
}
local j=`j'+1
}

* save results
keep var_year var_f*
sort var_year 
merge using results_graphs_q.dta
drop _merge

save results_graphs_q.dta, replace


* loop on gender
local gender=1
while `gender'<=2{


u data_`gender', clear

gen var_year=_n+1977

local k=10
while `k'<=90{
gen var_`gender'_q`k'_nosel=.
local k=`k'+10
}

local j=78
while `j'<=100{
_pctile lw if year==`j', p(10 20 30 40 50 60 70 80 90)
local k=10
while `k'<=90{
local l=`k'/10
replace var_`gender'_q`k'_nosel=r(r`l') if var_year==1900+`j'
local k=`k'+10
}
local j=`j'+1
}

* save results
keep var_year var_`gender'*
sort var_year 
merge using results_graphs_q.dta
drop _merge

save results_graphs_q.dta, replace




local gender=`gender'+1
}

* aggregate distribution

* uncomment if baseline results
infile lw year a b c using "C:\Dfile\Dossiers\Textes\Quantiles\Codes\Quantiles_stata\Matres_m.txt", clear 

* uncomment if bb8
*infile lw year a b c using "C:\Dfile\Dossiers\Textes\Quantiles\Codes\Quantiles_stata\Matbb8_m.txt", clear 

save inter, replace

* uncomment if baseline results
infile lw year a b c using "C:\Dfile\Dossiers\Textes\Quantiles\Codes\Quantiles_stata\Matres_f.txt", clear 

* uncomment if bb8
*infile lw year a b c using "C:\Dfile\Dossiers\Textes\Quantiles\Codes\Quantiles_stata\Matbb8_f.txt", clear 

append using inter
save inter, replace


gen var_year=_n+1977

local k=10
while `k'<=90{
gen var_q`k'=.
local k=`k'+10
}

local j=78
while `j'<=100{
_pctile lw if year==`j', p(10 20 30 40 50 60 70 80 90)
local k=10
while `k'<=90{
local l=`k'/10
replace var_q`k'=r(r`l') if var_year==1900+`j'
local k=`k'+10
}
local j=`j'+1
}

* save results
keep var_year var_q*
sort var_year 
merge using results_graphs_q.dta
drop _merge

save results_graphs_q.dta, replace

* aggregate distributions, no selection

u data_1, clear
append using data_2

gen var_year=_n+1977

local k=10
while `k'<=90{
gen var_q`k'_nosel=.
local k=`k'+10
}

local j=78
while `j'<=100{
_pctile lw if year==`j', p(10 20 30 40 50 60 70 80 90)
local k=10
while `k'<=90{
local l=`k'/10
replace var_q`k'_nosel=r(r`l') if var_year==1900+`j'
local k=`k'+10
}
local j=`j'+1
}

* save results
keep var_year var_q*
sort var_year 
merge using results_graphs_q.dta
drop _merge

save results_graphs_q.dta, replace





* graphs
use results_graphs_q.dta, clear
local k=10
while `k'<=90{
twoway scatter var_m_q`k' var_1_q`k'_nosel var_f_q`k' var_2_q`k'_nosel var_year if var_year<=2000, /*
*/ c(l l l l) ms(p p p p) lwidth(thick thick medthick medthick) lpattern(dash solid dash solid) legend(off) xtitle("year",size(large)) ytitle("log wage",size(large))

* uncomment if baseline results
graph export "C:\Dfile\Dossiers\Quantiles\fig`k'.eps", as(eps) preview(off) replace

* uncomment if bb8 copula
*graph export "C:\Dfile\Dossiers\Quantiles\figbb8`k'.eps", as(eps) preview(off) replace

* (optional pause)
sleep 10000 
local k=`k'+10
}

